<?php

namespace Repository;

use Doctrine\DBAL\Connection;
use Util\InstanceProvider;
use Teknisa\Model\Traits\TQuery;
use Zeedhi\DevOps\Util\Utilities;

class Soliserv
{
    use TQuery;

    public function findSoliservById($soliservId, $situationFilters, $userId)
    {
        $gepOpened  = $situationFilters['GEP']['OPENED'];
        $gepWaiting = $situationFilters['GEP']['WAITING'];
        $gepClosed  = $situationFilters['GEP']['CLOSED'];
        $validate = \Util\Utilities::getValidateBudgetFaseGep();
        $refuse = \Util\Utilities::getRefuseBudgetFaseGep();
        $query = <<<SQL
        SELECT  SER.NRSOLISERV AS ID, SER.NRORG, SER.DSREFESOLI AS REFERENCE,
                SER.CDOPERINCLUSAO AS CREATED_BY, SER.NRLICENCAUSO AS USE_LICENSE,
                DES.DSSOLISERV AS DESCRIPTION, SER.CDOPERINCLUSAO AS REPORTER_BY,
                TO_CHAR((SELECT MAX(LFT.DTINCLUSAO) FROM LOGFASETRAM LFT WHERE (LFT.NRSOLISERV = :SOLISERV_ID AND LFT.CDFILIAL = SER.CDFILIAL) ), 'DD/MM/YYYY') AS UPDATED_AT,
                SER.CDPRODCOMP AS PRODUCT, 'S' AS TYPE, OPE.NMOPERADOR AS REPORTER_NAME,
                '' AS CAUSE, SER.CDOPERULTATU AS UPDATED, PRO.CDPRODUTO AS BOARD,
                SER.CDPRODGRUP AS PRODUCT_TYPE, PRT.NMPRODUTO AS PRODUCT_TYPE_NAME, CLI.NMRAZSOCCLIE,
                ASS.NMASSUNTO AS CLASSIFICATION_NAME, ASS.IDORIGOBRSOL AS CLASSIFICATION_IDORIGOBRSOL,
                PRO.NMPRODUTO AS PRODUCT_NAME, ASS.CDASSUNTO AS CLASSIFICATION,
                 CASE WHEN SER.CDFASETRAM IN ('$validate')
                       THEN 'Y'
                       ELSE 'N'
                     END AS ENABLE_APPROVAL,
                 CASE WHEN EXISTS (   SELECT NRSEQORCAMENTO AS EXTERNAL_ID
                                        FROM FCT_ORCAMENTO
                                       WHERE NRSOLISERV = SER.NRSOLISERV
                                         AND IDATIVO = 'S'
                                         AND IDSITUACAOORCAMENTO <> 'CANCELADO')
                       THEN 'Y'
                       ELSE 'N'
                 END AS IS_INTEGRATION_SM,
                CASE WHEN $gepWaiting AND SER.CDFASETRAM NOT IN (SELECT CDFATRAMENCE FROM PARAMGERAL PARA WHERE PARA.NRORG = SER.NRORG)
                     THEN 'Y'
                     ELSE 'N'
                 END AS ENABLE_CLOSED,
                CASE WHEN $gepClosed
                     THEN 'Fechado'
                     WHEN $gepWaiting
                     THEN 'Aguardando ação do cliente'
                     WHEN $gepOpened
                     THEN 'Em aberto'
                     ELSE 'Em progresso'
                END AS STATUS,
                CASE WHEN $gepWaiting
                     THEN 'Y'
                     ELSE 'N'
                 END AS WAITING,
                (SELECT S.NRSOLISERV
                   FROM SOLISERV S
                   JOIN ORCASOLICITA O ON (O.CDFILIAL = S.CDFILIAL AND O.NRSOLISERV = S.NRSOLISERV)
                  WHERE S.NRSOLISERV = :SOLISERV_ID
                    AND ROWNUM = 1
                    AND  (SELECT CDFASETRAM
                                   FROM ( SELECT CDFASETRAM
                                            FROM LOGFASETRAM LFT
                                           WHERE LFT.NRSOLISERV = :SOLISERV_ID
                                             AND CDFASETRAM IN ('$refuse','$validate')
                                        ORDER BY DTALFASETRAM DESC)
                                  WHERE ROWNUM = 1) IN ('$validate')) AS WITH_BUDGET,
                SER.CDVERPROORIG AS PRODUCT_VERSION, SER.CDVERPROORIG AS PRODUCT_VERSION_LABEL,
                SER.CDRELVERORIG AS PRODUCT_RELEASE, SER.CDRELVERORIG AS PRODUCT_RELEASE_LABEL,
                SER.CDPATRELORIG AS PRODUCT_PATCH, SER.CDPATRELORIG AS PRODUCT_PATCH_LABEL
         FROM  SOLISERV SER
         JOIN  DESCSOLI DES ON DES.NRSOLISERV = SER.NRSOLISERV
         JOIN  OPERADOR OPE ON OPE.CDOPERADOR = SER.CDOPERADOR
         JOIN  PRODUTO PRO  ON PRO.CDPRODUTO = SER.CDPRODCOMP
    LEFT JOIN  PRODUTO PRT  ON PRT.CDPRODUTO = SER.CDPRODGRUP
         JOIN  ASSUNTO ASS  ON ASS.CDASSUNTO = SER.CDASSUNTO
    LEFT JOIN CLIENTE CLI ON CLI.CDCLIENTE = SER.CDCLIENTE
        WHERE  SER.NRSOLISERV = :SOLISERV_ID
SQL;

        $params = array(
            "SOLISERV_ID" => $soliservId,
            "USER_ID" => $userId
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);

        return count($result) > 0 ? $result[0] : array();
    }

    public function getUnsentEmails($commentDateString,$callRelationship){
        $query = <<<SQL
        SELECT OPR.DSEMAILOPER,
               LFT.CDFILIAL, LFT.NRSOLISERV, TO_DATE(LFT.DTALFASETRAM) AS DTALFASETRAM,  SER.DSREFESOLI, OPA.NMOPERADOR,
               OPE.NMOPERADOR AS SOLI, OPE.CDOPERADOR AS SOLICD, OPR.NMOPERADOR AS RESP, OPR.CDOPERADOR AS RESPCD,
               LFT.DSALFASETRAM, LFT.TXACAOLFTRAM
          FROM SOLISERV SER
          JOIN LOGFASETRAM LFT ON SER.NRSOLISERV = LFT.NRSOLISERV
          JOIN OPERADOR OPR ON OPR.CDOPERADOR = LFT.CDOPERRESP
          JOIN OPERADOR OPE ON OPE.CDOPERADOR = LFT.CDOPERADOR
          JOIN OPERADOR OPA ON OPA.CDOPERADOR = SER.CDOPERADOR
         WHERE OPR.DSEMAILOPER IS NOT NULL
           AND LFT.IDEMAILENV = 'N'
           AND LFT.CDOPERRESP <> LFT.CDOPERADOR
           AND ((SER.CDCLIENTE = OPR.CDCLIENTE) OR (SER.CDCLIENTE = OPE.CDCLIENTE))
           AND SER.NRSOLISERV = :SOLISERV_ID
           AND TO_CHAR(LFT.DTALFASETRAM,'DDMMYYYYHH24MISS') = :FASE_ID
SQL;
        $params = array(
            "SOLISERV_ID" => $callRelationship,
            "FASE_ID" => $commentDateString
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findBudget($callRelationship,$proposalTitle = 'Proposta' ,$discountTitle = 'Desconto',
                               $namePercent = 'Percentual'){
        $query = <<<SQL
        SELECT 
    '  '||'$proposalTitle' AS TYPE_ORDER,
     NVL(VAL.VRITORCACLIE, NVL(ORC.VRITORCACLIS, 0)) AS ITEM_VALUE,
     NVL(ORC.QTITORCSOLIC, 0) AS PROPOSAL_QUANTITY,
     NVL(ORC.VRORCADOSOLI, 0) AS PROPOSAL_VALUE,
     NVL(ORC.QTITORCSOCAL, 0) AS PROPOSAL_QUANTITY_ESTIMAT,
     NVL(ORC.VRORCSOLICAL, 0) AS PROPOSAL_VALUE_ESTIMAT,
     NVL(ORC.QTITORCSOCAN, 0) AS PROPOSAL_QUANTITY_BEFORE,
     TO_CHAR(ITMN.CDITORCAPROD) AS BUDGET_ITEM_ID,
     ITMN.NMITORCAPROD AS ITEM_NAME,
     ITMN.CDITORCAPROD,
     CASE WHEN CURRENT_DATE BETWEEN VAL.DTINIVAITO12 AND VAL.DTINIVAITO13 THEN
        'ALERT_CLIE'
        WHEN CURRENT_DATE > VAL.DTINIVAITO13 THEN
        'ERRO_CLIE'
        WHEN VAL.VRITORCACLIE  < 0 THEN
        'ALERT_CLIE_ITEM_VR'
        ELSE
        NULL        
     END AS CODE_MESAGER,
     :SOLISERV_ID AS NRSOLISERV,
     ORC.NRSOLISERV AS NOT_NEW,
      NVL((SELECT DSUNIDADE
          FROM ITEMORCAPROD ITPROD
          JOIN UNIDMEDIDA UNID
            ON ITPROD.SGUNIDADE = UNID.SGUNIDADE
         WHERE CDITORCAPROD = ORC.CDITORCAPROD),'Horas') AS UNIT_MEASURE,
        NVL(VAL.VRITORCACLIE, NVL(ORC.VRITORCACLIS, 0)) AS ITEM_VALUE_TRUE
        FROM ITEMORCAPROD_FCT_ITEMORCAMENTO ITEMSM
        LEFT JOIN ITEMORCAPROD ITMN ON (ITMN.CDITORCAPROD = ITEMSM.CDITORCAPROD)
        LEFT JOIN ORCASOLICITA ORC ON ORC.CDITORCAPROD = ITEMSM.CDITORCAPROD AND ORC.NRSOLISERV = :SOLISERV_ID
        JOIN SOLISERV SOL ON SOL.NRSOLISERV = :SOLISERV_ID 
        JOIN ( SELECT NVL(ITCLI.VRITORCACLIE, NULL) AS VRITORCACLIE,VAL.DTINIVAITORC,VAL.DTINIVAITO12,VAL.DTINIVAITO13,
                ITCLI.CDITORCAPROD
            FROM ITEMORCACLIE ITCLI
            JOIN SOLISERV SOL ON SOL.NRSOLISERV = :SOLISERV_ID AND SOL.CDCLIENTE = ITCLI.CDCLIENTE
            JOIN  (SELECT MAX(ITCLI.DTINIVAITORC) AS DTINIVAITORC,
                          add_months(MAX(ITCLI.DTINIVAITORC),12) AS DTINIVAITO12,
                          add_months(MAX(ITCLI.DTINIVAITORC),13) AS DTINIVAITO13
                                            FROM ITEMORCACLIE ITCLI
                                            JOIN SOLISERV SOL ON SOL.NRSOLISERV = :SOLISERV_ID AND SOL.CDCLIENTE = ITCLI.CDCLIENTE
                                            WHERE (DTINIVAITORC < CURRENT_DATE)) VAL ON ITCLI.DTINIVAITORC = VAL.DTINIVAITORC) VAL ON VAL.CDITORCAPROD =  ITMN.CDITORCAPROD
        
    UNION ALL
    SELECT  ' '||'$discountTitle' AS TYPE_ORDER,
                    null AS ITEM_VALUE,
                    NVL(NVL(SOL.VRPEDESORCAM , 0) , 0) AS PROPOSAL_QUANTITY,
                    NVL(-SOL.VRDESCORCAM, 0) AS PROPOSAL_VALUE,
                    NULL AS PROPOSAL_QUANTITY_ESTIMAT,
                    NULL AS PROPOSAL_VALUE_ESTIMAT,
                    0 AS PROPOSAL_QUANTITY_BEFORE,
                    '999999XXXX' AS BUDGET_ITEM_ID,
                    ' ' AS ITEM_NAME,  
                    ' ' AS CDITORCAPROD,
                    ' ' AS CODE_MESAGER,
                    :SOLISERV_ID AS NRSOLISERV,
                    null AS NOT_NEW,
                    '$namePercent' AS UNIT_MEASURE,
                    NVL(null, 0) AS ITEM_VALUE_TRUE
               FROM SOLISERV SOL
              WHERE SOL.NRSOLISERV = :SOLISERV_ID
    ORDER BY  TYPE_ORDER  ,CDITORCAPROD  
SQL;
        $params = array(
            "SOLISERV_ID" => $callRelationship
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findTarefa($nrsoliserv,$cdassuntoEspec){
        $query = <<<SQL
        SELECT TAR.CDFILIAL ,ASS.NMASSUNTO ,OPER.NMOPERADOR,
         CASE WHEN TAR.IDORIGTARE  = '1'
                       THEN 'Tarefa '
                       ELSE 'Orçamento'
                     END AS TAREFA_TYPE ,
           CASE WHEN ASS.CDASSUNTO  IN ('$cdassuntoEspec')
                       THEN 'S'
                       ELSE 'N'
                     END AS IS_ESPEC ,          
            TAR.NRTAREFA ,TAR.DSREFETAREFA ,TAR.CDPROCESSO ,TAR.CDPROJETO ,TAR.NRBASELINEPR ,TAR.NRSOLISERV ,TAR.CDPRODGRUP ,TAR.CDREQPROD ,TAR.NRSEQREQPROD ,
            TAR.CDASSUNTO ,TAR.CDCLIENTE ,TAR.CDPROSPECT ,TAR.CDFORNECED ,TAR.NRLICENCAUSO ,TAR.CDOPERRESP ,TAR.CDOPERABER ,TAR.CDOPERCONC ,TAR.DTALFASETRAM ,
            TAR.DTABERTAREFA ,TAR.DTCONCTAREFA ,TAR.IDSITTAREFA ,TAR.IDTIPTAREFA ,TAR.QTSEGAVISTAR ,TAR.IDORIGTARE ,TAR.NRTAREFAORIG ,TAR.NRREPETTARE ,
            TAR.NMCONTATADO ,TAR.NRPRIOTAREFA ,TAR.DTHRREUNIAO ,TAR.DTULTATUTARE ,TAR.QTHRREUNIAO ,TAR.CDPRODCOMP ,TAR.IDTARATEFAT ,TAR.CDTELAITEMTRAB ,TAR.NRORG ,
            TAR.DTINCLUSAO ,TAR.DTULTATU ,TAR.NRORGINCLUSAO ,TAR.CDOPERINCLUSAO ,TAR.NRORGULTATU ,TAR.CDOPERULTATU ,TAR.IDATIVO 
        FROM TAREFA TAR        
        LEFT JOIN  ASSUNTO ASS  ON ASS.CDASSUNTO = TAR.CDASSUNTO
        LEFT JOIN OPERADOR OPER ON TAR.CDOPERRESP = OPER.CDOPERADOR
        WHERE TAR.NRSOLISERV = :SOLISERV_ID
        AND TAR.IDORIGTARE <> '4'
SQL;
        $params = array(
            "SOLISERV_ID" => $nrsoliserv,
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }

    public function findAllSoliserv(){
        $page = $this->getPage();
        $limit = $this->getLimit();
        $search = $this->getSearch();
        $searchIn =  $this->getSearchIn();
        $find =  $this->getFind();
        $dynamicFilter = $this->getDynamicFilter();
        $conditions = $search ? $this->createAndSearch($search, $searchIn) : '';
        $conditions .= $this->createFind($find, 'AND');
        $conditions .= $dynamicFilter ? $this->createDynamicFilter($dynamicFilter, 'AND') : '';
        $query = <<<SQL
         SELECT S.NRSOLISERV,  S.DSREFESOLI, A.NMASSUNTO, S.NRSOLIORIG
           FROM SOLISERV S, ASSUNTO A
          WHERE S.CDASSUNTO = A.CDASSUNTO
          $conditions
          AND ROWNUM <= $limit
SQL;

        $data = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query);
        return $this->buildResponseData($data, $page, $limit);
    }

    public function MaintenanceCost($organizationId)
    {

        $query =
            <<<SQL
              SELECT DISTINCT
               MA.VRPERCMANUCUSTOM AS MAINTENANCE_PERCENTAGE
          FROM (SELECT CDSERVORCA, NMSERVORCA
                  FROM FCT_SERVICOORCA
                 WHERE IDLICENUSOMANUT = 'L'
                   AND IDATIVO = 'S'
                   AND NRORG = :nrorg) LU,
               (SELECT FCT_SERVICOORCA.CDSERVORCA, FCT_SERVICOORCA.NMSERVORCA, 
                       FCT_SERVICOORCA.VRPERCMANUCUSTOM, FCT_SERVICOORCA.NRESCOPOMANUCUSTOM,
                       FCT_TIPOORCAMENTO.NMTIPOORCAMENTO
                  FROM FCT_SERVICOORCA
                  LEFT JOIN FCT_TIPOORCAMENTO
                    ON FCT_TIPOORCAMENTO.NRTIPOORCAMENTO = FCT_SERVICOORCA.NRESCOPOMANUCUSTOM
                   AND FCT_TIPOORCAMENTO.NRORG = FCT_SERVICOORCA.NRORG
                 WHERE FCT_SERVICOORCA.IDLICENUSOMANUT = 'M'
                   AND FCT_SERVICOORCA.IDATIVO = 'S'
                   AND FCT_SERVICOORCA.NRORG = :nrorg) MA,
               (SELECT CDTPMEDIDASERV, DSTPMEDIDASERV
                  FROM FCT_TIPOMEDIDASERV
                 WHERE IDATIVO = 'S'
                   AND NRORG = :nrorg) QT
SQL;

        $params = array(
            "nrorg" => $organizationId
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);
        return empty($result) ? null : $result[0]['MAINTENANCE_PERCENTAGE'];
    }

    public function findManutSoliservBudget($issueId) {
        $query =
            <<<SQL
             SELECT ORC.NRSOLISERV,
                           NVL(SUM(ORC.VRORCADOSOLI), 0) AS TOTAL_VALUE, 1 as TYPE
                      FROM ORCASOLICITA ORC
                      JOIN ITEMORCAPROD_FCT_ITEMORCAMENTO ITEMSM
                        ON ORC.CDITORCAPROD = ITEMSM.CDITORCAPROD
                       AND ORC.NRORG        = ITEMSM.NRORG
                     WHERE ORC.NRSOLISERV = '$issueId'
                       AND ORC.CDFILIAL   = 9999
                       AND ORC.NRORG      = 20
                       GROUP by  ORC.NRSOLISERV                        

SQL;
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query);
        return empty($result) ? 0 : $result[0]['TOTAL_VALUE'];
    }

    public function findManutSoliservDiscount($issueId) {
        $query =
            <<<SQL
           SELECT NVL(VRDESCMANUT,0) AS MAINTENANCE_VALUE ,NVL(VRPEDESMANUT,0) AS MAINTENANCE_PERCENT FROM SOLISERV SOL
            WHERE SOL.NRSOLISERV = '$issueId'        

SQL;
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query);
        return $result;
    }

    public function findValidateBudget($nrsoliserv) {
        $query =
            <<<SQL
          SELECT SUBSTR(MAX(TO_CHAR(DTALFASETRAM, 'YYYYMMDDHH24MISS')||'_'||CDFASETRAM), -3) AS CDFASETRAM,
           (
                 SELECT MAX(NRORCAMENTO) AS NRORCAMENTO
                       FROM FCT_ORCAMENTO
                      WHERE NRSOLISERV = :NRSOLISERV
                        AND IDSITUACAOORCAMENTO = 'ACEITO' ) AS NRORCAMENTO
           FROM LOGFASETRAM
          WHERE NRSOLISERV = :NRSOLISERV
            AND CDFASETRAM IN ('088', '067', '063', '050')
            GROUP BY NRSOLISERV

SQL;
        $params = array(
            "NRSOLISERV" => $nrsoliserv,
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
        return $result;
    }

    public function findBudgetPlotsToDelete($budgetId,$lastParcel) {
        $query =
            <<<SQL
       SELECT  BPS.NRPARCSOLI AS ID
        FROM PARCSOLISERV BPS
        WHERE BPS.NRSOLISERV = :BUDGET_ID
        AND BPS.NRPARCSOLI > $lastParcel
        
SQL;

        $params = array(
            "BUDGET_ID" => $budgetId,
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);
        $result = Utilities::getArrayFromArrayAssociative($result);
        return $result;
    }

    public function findSoliBudgetPlots($issueId,$namePlots ='Parcela') {
        $query =
            <<<SQL
        SELECT NRPARCSOLI||'° $namePlots' AS ORDER_PLOTS,
                NRPARCSOLI AS ORDER_PLOTS_NUM, NRSOLISERV AS BUDGET_ID,
                VRPARCSOLI as VALUE_PLOTS,NRSOLISERV, NRPARCSOLI * 30 as DAYS_PAYMENT, 'Parcelas' AS GROUPBY,
                 NVL((SELECT    NVL(SUM(ORC.VRORCADOSOLI), 0) - NVL(MAX(SOL.VRDESCORCAM),0) AS TOTAL_VALUE_DEC
                      FROM ORCASOLICITA ORC
                      JOIN ITEMORCAPROD_FCT_ITEMORCAMENTO ITEMSM
                        ON ORC.CDITORCAPROD = ITEMSM.CDITORCAPROD                        
                  JOIN SOLISERV SOL ON SOL.NRSOLISERV = ORC.NRSOLISERV
                       AND ORC.NRORG        = ITEMSM.NRORG
                     WHERE ORC.NRSOLISERV = '$issueId'
                       AND ORC.CDFILIAL   = 9999
                       AND ORC.NRORG      = 20
                       GROUP by  ORC.NRSOLISERV),0) AS PROPOSAL_VALUE
                  FROM PARCSOLISERV
                 WHERE CDFILIAL     = 9999
                   AND NRSOLISERV   = '$issueId'
                   AND NRORG        = 20
                 ORDER BY NRPARCSOLI
        
SQL;

        $params = array(
            "ISSUE_ID" => $issueId
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);
        return $result;
    }

    public function getNrsequittare($nrtarefa,$cdfilial){
        $query = <<<SQL
           SELECT LPAD(TO_CHAR(TO_NUMBER(NVL(MAX(I.NRSEQUITTARE),'0')) + 1),10,'0') NRPRXSEQUITTR
             FROM ITEMTAREFA I
            WHERE (I.CDFILIAL = :P_CDFILIAL) AND
                  (I.NRTAREFA = :P_NRTAREFA)
        
SQL;
        $params = array(
            "P_NRTAREFA" => $nrtarefa,
            "P_CDFILIAL" => $cdfilial,
        );

        $result =  InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);

        return count($result) > 0 ? $result[0]['NRPRXSEQUITTR'] : null;
    }

    public function getParFilialGep($cdfilial){
        $query = <<<SQL
            SELECT DSDIRWEBFONT, DSDIRWINFONT, VRPESOALTCPX, CDSETORPROC, CDNVPESQPROC
              FROM PAR_FILIAL_GEP 
             WHERE CDFILIAL = :P_CDFILIAL
        
SQL;
        $params = array(
            "P_CDFILIAL" => $cdfilial,
        );

        $result =  InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);

        return count($result) > 0 ? $result[0] : null;
    }

    public function findActivitiesGeneration($cdarvprocess, $cdnvprocesso){
        $query = <<<SQL
        SELECT P.CDPROCESSO, P.CDNVPROCESSO, P.CDARVPROCESS, P.NMPROCESSO, P.IDTPPROCESSO,
               P.CDSETOR, P.IDPROCORRES, P.IDPROREUNIAO, P.IDINCAUTPROC, P.CDOPERADOR,
               NVL(P.VRFATOCPLX, 1) AS VRFATOCPLX, P.IDGERATVCONS, P.IDREFECPLX, S.NMSETOR,
               D.NMDEPTO, O.NMOPERADOR, P.VRPRODMEDES, P.QTTEMPMINATIV,
                  CASE WHEN P.IDGERATVCONS  = 'S'
                       THEN 'Sim'
                       ELSE 'Nâo'
                     END AS IDGERATVCONS_LABEL ,
                  CASE WHEN P.IDREFECPLX  = 'A'
                       THEN 'Alteração'
                       ELSE 'Item de Trabalho'
                     END AS IDREFECPLX_LABEL 
          FROM PROCESSO P, SETOR S, DEPARTAMENTO D, OPERADOR O
         WHERE (P.CDSETOR = S.CDSETOR(+))
           AND (S.CDDEPTO = D.CDDEPTO(+))
           AND (P.CDOPERADOR = O.CDOPERADOR(+))
           AND (P.IDINCAUTPROC = 'S')
           AND (P.CDNVPROCESSO = :P_CDNVPROCESSO)
           AND (P.CDARVPROCESS LIKE (:P_CDARVPROCESS || '%'))
         ORDER BY CDARVPROCESS

        
SQL;
        $params = array(
            "P_CDARVPROCESS" => $cdarvprocess,
            "P_CDNVPROCESSO" => $cdnvprocesso,
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }

    public function findProcessGeneration($cdsetor, $cdnvprocesso){
        $query = <<<SQL
        SELECT CDARVPROCESS, NMPROCESSO ,CDARVPROCESS as ID_TREE
          FROM PROCESSO
         WHERE CDNVPROCESSO = :P_CDNVPROCESSO
           AND CDSETOR = :P_CDSETOR
         ORDER BY CDARVPROCESS
        
SQL;
        $params = array(
            "P_CDSETOR" => $cdsetor,
            "P_CDNVPROCESSO" => $cdnvprocesso,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }

    public function findItemTarefa($nrtarefa,$nrsoliserv){
        if(empty($nrtarefa)){
            $nrtarefa = array();
        }

        $query = <<<SQL
        SELECT  I.NRTAREFA,TAR.NRSOLISERV, I.NRTAREFA||'_'||I.NRSEQUITTARE AS ID, I.NRPRIOITTARE,I.CDITEMTRAB,
         T.CDREDUITTRAB || ' - ' || T.NMITEMTRAB AS ITEM_TRABALHO, I.NRCPLXIMPLEM, I.NRCPLXITEMTB, I.NRSEQUITTARE,
         'N' AS IDCHECK, I.DSREFEITTARE, I.DTINCLITTARE, I.TXPLANITTARE, I.CDFILIAL,
           I.CDOPERADOR, I.CDOPERRESP, I.NRCPLXITTARE, T.NRCPLXITTRAB, '' AS ESPECIFICATION,
           T.CDREDUITTRAB||' - '||T.NMITEMTRAB AS ITEMTRABALHO, P.NMOPERADOR AS NMOPERRESP
          FROM ITEMTAREFA I
          JOIN ITEMTRAB T ON (I.CDITEMTRAB = T.CDITEMTRAB)
          JOIN TAREFA TAR ON (TAR.NRTAREFA = I.NRTAREFA)
          LEFT JOIN OPERADOR P ON (I.CDOPERRESP = P.CDOPERADOR) 
         WHERE TAR.NRSOLISERV= :SOLISERV_ID
         AND I.NRTAREFA IN (:P_NRTAREFA)
         ORDER BY I.NRPRIOITTARE, I.NRSEQUITTARE
        
SQL;
        $params = array(
            "P_NRTAREFA" => $nrtarefa,
            "SOLISERV_ID" => $nrsoliserv,
        );

        $types = array(
            "P_NRTAREFA" => Connection::PARAM_STR_ARRAY,
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params,$types);
    }

    public function findAddItemTarefa(){

        $query = <<<SQL
        SELECT CDREDUITTRAB, NMITEMTRAB,  CDITEMTRAB, NRCPLXITTRAB
          FROM ITEMTRAB
      ORDER BY 1
        
SQL;

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query);
    }

    public function findTarefaAllResponsavel($nrsoliserv){
        $query = <<<SQL
        SELECT OP.CDOPERADOR, OP.NMOPERADOR
  FROM (SELECT OP.CDOPERADOR, OP.NMOPERADOR
          FROM OPERADOR OP, OPERPROJETO OJ, BASELINEPROJ BL, SOLIBASELINE SL, PROJETO PR
         WHERE SL.NRSOLISERV = :P_NRSOLISERV
           AND PR.CDPROJETO = BL.CDPROJETO
           AND SL.CDFILIAL = BL.CDFILIAL
           AND SL.CDPROJETO = BL.CDPROJETO
           AND OP.IDOPERATIVO = 'A'
           AND BL.CDOPERRESP = OP.CDOPERADOR
           AND OP.CDOPERADOR = OJ.CDOPERADOR
           AND BL.CDPROJETO = OJ.CDPROJETO
           AND BL.NRBASELINEPR = (SELECT MAX(B.NRBASELINEPR)
                                    FROM BASELINEPROJ B
                                   WHERE B.CDFILIAL = BL.CDFILIAL
                                     AND B.CDPROJETO = BL.CDPROJETO
                                     AND B.NRBASELINEPR = BL.NRBASELINEPR
                                     AND B.IDSITBASELIN = BL.IDSITBASELIN)
         UNION
        SELECT OP.CDOPERADOR, OP.NMOPERADOR
          FROM OPERADOR OP, OPERPROJETO OJ, BASELINEPROJ BL, SOLIBASELINE SL, PROJETO PR
         WHERE SL.NRSOLISERV = :P_NRSOLISERV
           AND PR.CDPROJETO = BL.CDPROJETO
           AND SL.CDFILIAL = BL.CDFILIAL
           AND SL.CDPROJETO = BL.CDPROJETO
           AND OP.IDOPERATIVO = 'A'
           AND OJ.CDOPERADOR = OP.CDOPERADOR
           AND BL.CDFILIAL = OJ.CDFILIAL
           AND BL.CDPROJETO = OJ.CDPROJETO
           AND BL.NRBASELINEPR = (SELECT MAX(B.NRBASELINEPR)
                                    FROM BASELINEPROJ B
                                   WHERE B.CDFILIAL = BL.CDFILIAL
                                     AND B.CDPROJETO = BL.CDPROJETO
                                     AND B.NRBASELINEPR = BL.NRBASELINEPR
                                     AND B.IDSITBASELIN = BL.IDSITBASELIN)) OP
 WHERE 1 = 1
 ORDER BY OP.CDOPERADOR
       
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
        );

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }

    public function findTarefaAssunto(){
        $query = <<<SQL
        SELECT CDASSUNTO, NMASSUNTO
          FROM ASSUNTO
      ORDER BY CDASSUNTO
       
SQL;

        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query);
    }

    public function findPlanativtare($cdfilial,$nrtarefa){
        $query = <<<SQL
        SELECT DISTINCT P.CDFILIAL, P.NRTAREFA, P.NRPRIOATIVTR, P.NRPLATIVTARE, P.CDOPERRESP, P.CDITEMTRAB,
               P.CDOPERINCL, P.CDPROCESSO, P.DTINCATIVTAR, P.NRCPLXITATIV, P.IDSITATIVTAR, T.NMITEMTRAB,
               T.CDREDUITTRAB, R.CDARVPROCESS, R.NMPROCESSO, ROUND(P.QTTEMPLAITAR,2) AS QTTEMPLAITAR, P.DTFIPATIVTAR,
               P.DTCONATIVTAR, R.VRPRODMEDES, P.NRCPLXPLANAT, O.NMOPERADOR AS NMOPERRESP, D.NMOPERADOR AS NMOPERINCL,
               NVL(R.VRFATOCPLX, 0) AS VRFATOCPLX, R.IDGERATVCONS, R.IDREFECPLX, P.QTHRINFATIVTAR, P.NRCPLXINFATIVTAR,
               R.NMPROCESSO || DECODE(T.NMITEMTRAB, '',' - ' || T.NMITEMTRAB,'') AS NAVIGATOR, P.IDATVTEMPALTCR,
               P.DTFIRATIVTAR, P.DSREFEATIVTARE,P.CDFILIAL|| '-' ||P.NRTAREFA|| '-' ||P.NRPLATIVTARE AS ID,
               CDREDUITTRAB||' - ' ||NMITEMTRAB AS NAME_PROCESSO,
               TRUNC(P.NRCPLXITATIV) || ':' || REPLACE(TO_CHAR(EXTRACT (MINUTE FROM NUMTODSINTERVAL(P.NRCPLXITATIV, 'HOUR' )),'00'),' ','') AS TIME_PLAN,
               TRUNC(P.QTHRINFATIVTAR) || ':' || REPLACE(TO_CHAR(EXTRACT (MINUTE FROM NUMTODSINTERVAL(P.QTHRINFATIVTAR, 'HOUR' )),'00'),' ','') AS TIME_EST
          FROM PLANATIVTARE P, OPERADOR O, OPERADOR D, ITEMTRAB T, PLATVRELITTR L, PROCESSO R, APROATIVTARE A
         WHERE L.CDFILIAL = :P_CDFILIAL
           AND L.NRTAREFA = :P_NRTAREFA         
           AND L.CDFILIAL = P.CDFILIAL
           AND L.NRTAREFA = P.NRTAREFA
           AND L.NRPLATIVTARE = P.NRPLATIVTARE
           AND P.CDOPERRESP = O.CDOPERADOR
           AND P.CDOPERINCL = D.CDOPERADOR
           AND P.CDITEMTRAB = T.CDITEMTRAB(+)
           AND P.CDPROCESSO = R.CDPROCESSO
           AND P.CDFILIAL = A.CDFILIAL(+)
           AND P.NRTAREFA = A.NRTAREFA(+)
           AND P.NRPLATIVTARE = A.NRPLATIVTARE(+)
SQL;

        $params = array(
            "P_NRTAREFA" => $nrtarefa,
            "P_CDFILIAL" => $cdfilial,
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }

    public function findDefaultTaskSoli($nrsoliserv,$currentCdoperador){
        $query = <<<SQL
      SELECT NRSOLISERV, DSREFESOLI AS DSREFETAREFA, CDASSUNTO, '$currentCdoperador' AS CDOPERRESP, '000' AS NRPRIOTAREFA,
            '1' AS IDORIGTARE,NRSOLISERV AS DSSOLISERV
        FROM SOLISERV SOL
       WHERE SOL.NRSOLISERV = :P_NRSOLISERV
               
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params)[0];
    }

    public function validateFornwardSoli($nrsoliserv, $cdfilial = '9999')
    {
        $query = <<<SQL
                 SELECT COUNT(PL.NRPLATIVTARE) AS "NRATIVTARE"
              FROM PLANATIVTARE PL, TAREFA T, PAR_FILIAL_GEP PFG
             WHERE T.CDFILIAL   = PL.CDFILIAL
               AND T.NRTAREFA   = PL.NRTAREFA
               AND T.CDFILIAL   = :P_CDFILIAL
               AND T.NRSOLISERV = :P_NRSOLISERV
               AND PL.CDPROCESSO <> '0000010703'
               AND PL.CDPROCESSO <> '0000011659'
               AND PL.CDPROCESSO <> '0000010709'
               AND T.IDORIGTARE <> '2'
               AND PL.IDSITATIVTAR <> 'C'
               AND PL.IDSITATIVTAR <> 'X'
               AND PFG.CDFILIAL = :P_CDFILIAL
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
            "P_CDFILIAL" => $cdfilial,
        );
        $return = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);
        return empty($return) ? 0 : intval($return[0]["NRATIVTARE"]);
    }

    public function findNextNrplativtare($nrtarefa,$cdfilial){
        $query = <<<SQL
      SELECT MAX(NRPLATIVTARE) AS  NRPLATIVTARE
        FROM PLANATIVTARE 
       WHERE NRTAREFA = :P_NRTAREFA
       AND CDFILIAL = :P_CDFILIAL

               
SQL;
        $params = array(
            "P_NRTAREFA" => $nrtarefa,
            "P_CDFILIAL" => $cdfilial,
        );
        $return = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params)[0];
        return empty($return) ? 1 : intval($return['NRPLATIVTARE'])+1;
    }
    public function findValidadeAtividateGerada($cdfilial,$nrtarefas,$cdprocessos,$cditemtrabalhos){
        $query = <<<SQL
        SELECT PLA.NRPLATIVTARE,PLA.CDPROCESSO,PLA.CDITEMTRAB,ITE.NMITEMTRAB,PRO.NMPROCESSO
          FROM PLANATIVTARE PLA
          JOIN ITEMTRAB ITE ON (ITE.CDITEMTRAB = PLA.CDITEMTRAB)
          JOIN PROCESSO PRO ON (PRO.CDPROCESSO = PLA.CDPROCESSO)
         WHERE PLA.CDFILIAL   = :P_CDFILIAL
           AND PLA.NRTAREFA   = :P_NRTAREFA
           AND PLA.CDPROCESSO IN (:P_CDPROCESSO)
           AND PLA.CDITEMTRAB IN (:P_CDITEMTRAB)
           AND PLA.IDSITATIVTAR <> 'C'
           AND PLA.CDPROCESSO NOT IN ('0000011631','0000010171','0000011269')
               
SQL;
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRTAREFA" => $nrtarefas,
            "P_CDPROCESSO" => $cdprocessos,
            "P_CDITEMTRAB" => $cditemtrabalhos,
        );

        $types = array(
            "P_CDPROCESSO" => Connection::PARAM_STR_ARRAY,
            "P_CDITEMTRAB" => Connection::PARAM_STR_ARRAY,
        );
        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params,$types);
    }

    public function findQryVerifCor($cdarvprocess){
        $query = <<<SQL
        SELECT PG.CDPROCESSO
          FROM GRUPROCESSO GP, PROCESGPROC PG, PARAMGPROC PA, PROCESSO PR
         WHERE GP.CDGRUPROCESSO = PG.CDGRUPROCESSO
           AND PA.CDGRUPROCESSO = GP.CDGRUPROCESSO
           AND PG.CDPROCESSO    = PR.CDPROCESSO
           AND PA.IDPARAMGPROC  = 'MACO'
           AND PR.CDARVPROCESS  = :P_CDARVPROCESS
               
SQL;
        $params = array(
            "P_CDARVPROCESS" => $cdarvprocess,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function qryOperGrup($cdoperador){
        $query = <<<SQL
       SELECT
           AU.IDAUTGRUPOP
        FROM
           AUTGRUPOP AU, GRUPOPER GR, OPERGRUPOP GP, OPERADOR OP
        WHERE
           AU.CDGRUPOPER  = GR.CDGRUPOPER AND
           GR.CDGRUPOPER  = GP.CDGRUPOPER AND
           GP.CDOPERADOR  = OP.CDOPERADOR AND
           OP.CDOPERADOR  = :P_CDOPERADOR
               
SQL;
        $params = array(
            "P_CDOPERADOR" => $cdoperador,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function qryLogTram($nrsoliserv, $cdfilial){
        $query = <<<SQL
            SELECT
               LOG.CDFILIAL    , LOG.NRSOLISERV  , LOG.DTALFASETRAM, LOG.CDFASETRAM ,
               LOG.CDOPERADOR  , LOG.DSALFASETRAM, LOG.CDOPERRESP  , OPE.NMOPERADOR ,
               FAS.DSSTFASETRAM, LOG.TXACAOLFTRAM, FAS.TXPERGFATRAM, FAS.NMFASETRAM ,
               FAS.CDGROPERRESP, FAS.IDATIVESPE  , FAS.IDLIBERANEXO, OPE.DSEMAILOPER,
               OPE1.NMOPERADOR AS NMOPERRESP     , OPE1.DSEMAILOPER AS DSEMAILOPRESP,
               RPAD(LOG.DSALFASETRAM,60,' ') AS DSALFASETRAM60,LOG.CDMOTITRAMITA,MOTTRA.NMMOTITRAMITA
            FROM
               LOGFASETRAM LOG, OPERADOR OPE, OPERADOR OPE1, FASETRAM FAS,MOTITRAMITACAO MOTTRA
            WHERE
               (LOG.CDMOTITRAMITA = MOTTRA.CDMOTITRAMITA(+)) AND
               (LOG.CDFILIAL    = :P_CDFILIAL)       AND
               (LOG.NRSOLISERV  = :P_NRSOLISERV)     AND
               (OPE.CDOPERADOR  = LOG.CDOPERADOR)    AND
               (OPE1.CDOPERADOR = LOG.CDOPERRESP)    AND
               (FAS.CDFASETRAM  = LOG.CDFASETRAM)
            ORDER BY
               LOG.DTALFASETRAM DESC
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
            "P_CDFILIAL" => $cdfilial,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findQryVerifVerif($cdfilial,$nrsoliserv){
        $query = <<<SQL
        SELECT TXREATIVTARE
          FROM TAREFA TR, PLANATIVTARE PL, RESPPLATIV RE
         WHERE TR.CDFILIAL     = PL.CDFILIAL
           AND TR.NRTAREFA     = PL.NRTAREFA
           AND PL.CDFILIAL     = RE.CDFILIAL
           AND PL.NRTAREFA     = RE.NRTAREFA
           AND PL.NRPLATIVTARE = RE.NRPLATIVTARE
           AND PL.CDPROCESSO   = '0000011058'
           AND PL.CDFILIAL     = :P_CDFILIAL
           AND TR.NRSOLISERV   = :P_NRSOLISERV
               
SQL;
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRSOLISERV" => $nrsoliserv,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findProposaByNrsoliserv($nrsoliserv){
        $query = <<<SQL
        SELECT NRSEQORCAMENTO 
         FROM FCT_ORCAMENTO 
        WHERE NRSOLISERV = :P_NRSOLISERV AND IDSITUACAOORCAMENTO <> 'CANCELADO' AND IDATIVO = 'S'
               
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function getProposalValues($nrsoliserv){
        $query = <<<SQL
        SELECT  NVL(VRDESCMANUT,0) AS MAINTENANCE_PERCENT ,
                NVL(VRPEDESMANUT,0) AS MAINTENANCE_VALUE, 
                SOL.CDCLIENTE AS SPONSOR,
                SOL.CDPRODGRUP AS PRODUTO,
                SOL.DSREFESOLI AS DESCRIPTION,
                SOL.CDOPERSOLI AS REPORTER,
                OPE.NMOPERADOR AS REPORTER_NAME,
                OPE.DSEMAILOPER AS REPORTER_EMAIL,
                SOL.VRPEDESORCAM AS DISCOUNT_PERCENT,
                SOL.VRDESCORCAM AS DISCOUNT_VALUE
           FROM SOLISERV SOL
      LEFT JOIN OPERADOR OPE ON (SOL.CDOPERSOLI = OPE.CDOPERADOR)
          WHERE SOL.NRSOLISERV = :P_NRSOLISERV
               
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params)[0];
    }

    public function getProposalItemValues($nrsoliserv){
        $query = <<<SQL
        SELECT NVL(ORC.QTITORCSOLIC, 0) AS "quantity",
                       NVL(ORC.VRORCADOSOLI, 0) AS "totalValue",
                       NVL(ORC.VRITORCACLIS, 0) AS "unitaryValue",
                       (SELECT DSUNIDADE
                          FROM ITEMORCAPROD ITPROD
                          JOIN UNIDMEDIDA UNID
                            ON ITPROD.SGUNIDADE = UNID.SGUNIDADE
                         WHERE CDITORCAPROD = ORC.CDITORCAPROD) AS "measurement",
                       ITEMSM.CDSERVORCA AS "id"
                  FROM ORCASOLICITA ORC
                  JOIN ITEMORCAPROD_FCT_ITEMORCAMENTO ITEMSM
                    ON ORC.CDITORCAPROD = ITEMSM.CDITORCAPROD
                   AND ORC.NRORG        = ITEMSM.NRORG
                 WHERE ORC.NRSOLISERV = :P_NRSOLISERV               
SQL;
        $params = array(
            "P_NRSOLISERV" => $nrsoliserv,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function getUrlIntegrationSM($organizationId, $baseUri = '')
    {

        $query =
            <<<SQL
             SELECT DSURLSM||'$baseUri' AS URI
             FROM OM_INTEGRACOES
             WHERE NRORG = :ORGANIZATION_ID
SQL;

        $params = array(
            "ORGANIZATION_ID" => $organizationId
        );
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query, $params);
        return empty($result) ? null : $result[0]['URI'];
    }

    public function findManutSoliDiscount($nrsoliserv) {
        $query =
            <<<SQL
            SELECT NVL(VRDESCMANUT,0) AS MAINTENANCE_VALUE ,NVL(VRPEDESMANUT,0) AS MAINTENANCE_PERCENT
              FROM SOLISERV SOL
             WHERE SOL.NRSOLISERV = $nrsoliserv
SQL;
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query);
        return $result;
    }

    public function findManutSoliBudget($nrsoliserv) {
        $query =
            <<<SQL
            SELECT NVL(VRDESCMANUT,0) AS MAINTENANCE_PERCENT ,NVL(VRPEDESMANUT,0) AS MAINTENANCE_VALUE
              FROM SOLISERV SOL
             WHERE SOL.NRSOLISERV = $nrsoliserv
SQL;
        $result = InstanceProvider::getEntityManager()->getConnection()->fetchAll($query);
        return $result;
    }

    public function findqryDescTarefa($cdfilial,$nrtarefa){
        $query = <<<SQL
        SELECT CDFILIAL, NRTAREFA, TXTAREFA
          FROM DESCTAREFA
         WHERE CDFILIAL = :P_CDFILIAL
           AND NRTAREFA = :P_NRTAREFA
               
SQL;
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRTAREFA" => $nrtarefa,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findqryPesoCargo($cdoperador){
        $query = <<<SQL
        SELECT ((100+ NVL(GC.VRPESOATIVGRC,0))/100) AS VRPESOATIVGRC
          FROM OPERADOR OP, GRUPO_CARGO GC, CARGO CA
         WHERE GC.CDGRUPOCARGO = CA.CDGRUPOCARGO
           AND OP.CDCARGO = CA.CDCARGO
           AND OP.CDOPERADOR = :P_CDOPERADOR
               
SQL;
        $params = array(
            "P_CDOPERADOR" => $cdoperador,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findqryRastreabilidade($cdfilial,$nrtarefa){
        $query = <<<SQL
        SELECT RA.CDFILIAL, RA.NRTAREFA, RA.CDITEMTRAB, IT.NRCPLXITTRAB
          FROM RASTREABTARE RA, ITEMTRAB IT
         WHERE RA.CDFILIAL   = :P_CDFILIAL
           AND RA.NRTAREFA   = :P_NRTAREFA
           AND RA.CDITEMTRAB = IT.CDITEMTRAB
           AND IDRASTREABHORIZ = 'S'
               
SQL;
        $params = array(
            "P_CDFILIAL" => $cdfilial,
            "P_NRTAREFA" => $nrtarefa,
        );

        return InstanceProvider::getEntityManager()->getConnection()->fetchAll($query,$params);
    }

    public function findProcessTotalized($cdfilial,$nrtarefa){
        $query = <<<SQL
         SELECT PRO.ID_TREE,PRO.NMPROCESSO,
                TRUNC(SUM(PRO.NRCPLXITATIV)) || ':' || REPLACE(TO_CHAR(EXTRACT (MINUTE FROM NUMTODSINTERVAL(SUM(PRO.NRCPLXITATIV), 'HOUR' )),'00'),' ','') AS TIME_PLAN
            FROM
            (SELECT DISTINCT P.CDFILIAL, P.NRTAREFA, P.NRPRIOATIVTR, P.NRPLATIVTARE, P.CDOPERRESP, P.CDITEMTRAB,
                           P.CDOPERINCL, P.CDPROCESSO, P.DTINCATIVTAR, P.NRCPLXITATIV, P.IDSITATIVTAR, T.NMITEMTRAB,
                           T.CDREDUITTRAB, R.CDARVPROCESS as ID_TREE, R.NMPROCESSO, ROUND(P.QTTEMPLAITAR,2) AS QTTEMPLAITAR, P.DTFIPATIVTAR,
                           P.DTCONATIVTAR, R.VRPRODMEDES, P.NRCPLXPLANAT, O.NMOPERADOR AS NMOPERRESP, D.NMOPERADOR AS NMOPERINCL,
                           NVL(R.VRFATOCPLX, 0) AS VRFATOCPLX, R.IDGERATVCONS, R.IDREFECPLX, P.QTHRINFATIVTAR, P.NRCPLXINFATIVTAR,
                           R.NMPROCESSO || DECODE(T.NMITEMTRAB, '',' - ' || T.NMITEMTRAB,'') AS NAVIGATOR, P.IDATVTEMPALTCR,
                           P.DTFIRATIVTAR, P.DSREFEATIVTARE,P.CDFILIAL|| '-' ||P.NRTAREFA|| '-' ||P.NRPLATIVTARE AS ID,
                           CDREDUITTRAB||' - ' ||NMITEMTRAB AS NAME_PROCESSO
                      FROM PLANATIVTARE P, OPERADOR O, OPERADOR D, ITEMTRAB T, PLATVRELITTR L, PROCESSO R, APROATIVTARE A
                     WHERE L.CDFILIAL = :P_CDFILIAL
                       AND L.NRTAREFA = :P_NRTAREFA         
                       AND L.CDFILIAL = P.CDFILIAL
                       AND L.NRTAREFA = P.NRTAREFA
                       AND L.NRPLATIVTARE = P.NRPLATIVTARE
                       AND P.CDOPERRESP = O.CDOPERADOR
                       AND P.CDOPERINCL = D.CDOPERADOR
                       AND P.CDITEMTRAB = T.CDITEMTRAB(+)
                       AND P.CDPROCESSO = R.CDPROCESSO
                       AND P.CDFILIAL = A.CDFILIAL(+)
                       AND P.NRTAREFA = A.NRTAREFA(+)
                       AND P.NRPLATIVTARE = A.NRPLATIVTARE(+) ) PRO
            GROUP BY PRO.ID_TREE,PRO.NMPROCESSO
        
SQL;
        $params = array(
            "P_NRTAREFA" => $nrtarefa,
            "P_CDFILIAL" => $cdfilial,
        );
        return $this->createAndExecuteQueryAndBuildResponseData(InstanceProvider::getEntityManager(), $query,$params);
    }
}
